Description Usage Arguments Details Value Author(s) References See Also Examples
View source: R/B2_LocalModelCompile.R
Compile the local models
1 | LocalModelCompile(data, dag = NULL, node.class = NULL)
|
data |
a |
dag |
|
node.class |
|
This function compiles the local models, including the conditional probability tables for discrete variables, and linear predictor potentials for continuous variables.
potsa list of discrete potentials (conditional probability tables)
for each discrete variable.
bagsa list of sets of continuous potentials (lppotentials), each set for a
continuous variables.
Han Yu
Cowell, R. G. (2005). Local propagation in conditional Gaussian Bayesian networks. Journal of Machine Learning Research, 6(Sep), 1517-1550.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.