Description Usage Arguments Details Value Author(s) References See Also Examples
Get the marginal distributions of multiple variables
1 | Marginals(tree, vars)
|
tree |
a |
vars |
a |
Get the marginal distributions of multiple variables. The function Marginals
returns a list of marginal distributions. The marginal distribution of a discrete variable
is a named vector of probabilities. Meanwhile, the marginal distributions of
continous variables in a CG-BN model are mixtures of Gaussian distributions.
To fully represent this information, the marginal of a continuous variable is represented by
a data.frame with three columns to specify
parameters for each Gaussian distribution in the mixture, which are
meanthe mean value of a Gaussian distribution.
sdthe standard deviation of a Gaussian distribution.
nthe number of Gaussian mixtures
marginalsa list of marginal distributions
typesa named vector indicating the types of the variables whose
marginals are queried: TRUE for discrete, FALSE for continuous.
Han Yu
Cowell, R. G. (2005). Local propagation in conditional Gaussian Bayesian networks. Journal of Machine Learning Research, 6(Sep), 1517-1550.
PlotMarginals for visualization of the marginal distributions,
SummaryMarginals for summarization of the marginal distributions of
continuous variables.
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.