Description Usage Arguments Value See Also Examples
View source: R/F2_SummaryMarginal.R
This function summary the marginal distributions of continuous variables by outputing the mean, standard deviation, and number of subpopulations
1 | SummaryMarginals(marginals)
|
marginals |
the marginal distributions obtained from |
a data.frame object containing information about the marginal distributions for continuous variables.
The marginal distributions of continous variables in a CG-BN model are mixtures of Gaussian distributions.
Therefore, besides the mean and standard deviation, the object has an additional column to specify the number of Gaussian
mixtures.
meanthe mean value of a Gaussian distribution.
sdthe standard deviation of a Gaussian distribution.
nthe number of Gaussian distributions in the mixture.
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.